@@ -78,13 +78,29 @@ enum e_test_type
   __TEST_TYPE_MAX,
 };
 
+struct thread_func
+{
+  pthread_startroutine_t fn;
+  bool stop_only_on_hang;
+};
+
 /****************************************************************************
  * Private Function Prototypes
  ****************************************************************************/
 
+static FAR void *usrsock_blocking_socket_thread(FAR void *param);
+static FAR void *usrsock_blocking_close_thread(FAR void *param);
+static FAR void *usrsock_blocking_connect_thread(FAR void *param);
+static FAR void *usrsock_blocking_setsockopt_thread(FAR void *param);
+static FAR void *usrsock_blocking_getsockopt_thread(FAR void *param);
+static FAR void *usrsock_blocking_recv_thread(FAR void *param);
+static FAR void *usrsock_blocking_send_thread(FAR void *param);
+static FAR void *usrsock_blocking_poll_thread(FAR void *param);
+
 /****************************************************************************
  * Private Data
  ****************************************************************************/
+
 static pthread_t tid[MAX_THREADS];
 static sem_t tid_startsem;
 static sem_t tid_releasesem;
@@ -92,6 +108,42 @@ static int test_sd[MAX_THREADS];
 static enum e_test_type test_type;
 static int test_flags;
 
+static struct thread_func thread_funcs[__TEST_TYPE_MAX] =
+{
+  [TEST_TYPE_SOCKET]      =
+  {
+    usrsock_blocking_socket_thread, false
+  },
+  [TEST_TYPE_CLOSE]       =
+  {
+    usrsock_blocking_close_thread, false
+  },
+  [TEST_TYPE_CONNECT]     =
+  {
+    usrsock_blocking_connect_thread, true
+  },
+  [TEST_TYPE_SETSOCKOPT]  =
+  {
+    usrsock_blocking_setsockopt_thread, false
+  },
+  [TEST_TYPE_GETSOCKOPT]  =
+  {
+    usrsock_blocking_getsockopt_thread, false
+  },
+  [TEST_TYPE_RECV]        =
+  {
+    usrsock_blocking_recv_thread, true
+  },
+  [TEST_TYPE_SEND]        =
+  {
+    usrsock_blocking_send_thread, true
+  },
+  [TEST_TYPE_POLL]        =
+  {
+    usrsock_blocking_poll_thread, true
+  },
+};
+
 /****************************************************************************
  * Public Data
  ****************************************************************************/
@@ -289,7 +341,8 @@ static void do_usrsock_blocking_getsockopt_thread(FAR void *param)
   sem_post(&tid_startsem);
   value = -1;
   valuelen = sizeof(value);
-  ret = getsockopt(test_sd[tidx], SOL_SOCKET, SO_REUSEADDR, &value, &valuelen);
+  ret = getsockopt(test_sd[tidx], SOL_SOCKET, SO_REUSEADDR, &value,
+                   &valuelen);
   TEST_ASSERT_EQUAL(-1, ret);
 
   /* Close socket */
@@ -325,7 +378,8 @@ static void do_usrsock_blocking_send_thread(FAR void *param)
 
   /* Connect socket. */
 
-  ret = connect(test_sd[tidx], (FAR const struct sockaddr *)&addr, sizeof(addr));
+  ret = connect(test_sd[tidx], (FAR const struct sockaddr *)&addr,
+                sizeof(addr));
   TEST_ASSERT_EQUAL(0, ret);
 
   /* Allow main thread to hang usrsock daemon at this point. */
@@ -373,7 +427,8 @@ static void do_usrsock_blocking_recv_thread(FAR void *param)
 
   /* Connect socket. */
 
-  ret = connect(test_sd[tidx], (FAR const struct sockaddr *)&addr, sizeof(addr));
+  ret = connect(test_sd[tidx], (FAR const struct sockaddr *)&addr,
+                sizeof(addr));
   TEST_ASSERT_EQUAL(0, ret);
 
   /* Allow main thread to hang usrsock daemon at this point. */
@@ -405,7 +460,9 @@ static void do_usrsock_blocking_poll_thread(FAR void *param)
   intptr_t tidx = (intptr_t)param;
   struct sockaddr_in addr;
   int ret;
-  struct pollfd pfd = {};
+  struct pollfd pfd = {
+  };
+
   bool test_abort = !!(test_flags & TEST_FLAG_DAEMON_ABORT);
   bool test_hang = !!(test_flags & TEST_FLAG_PAUSE_USRSOCK_HANDLING);
 
@@ -423,7 +480,8 @@ static void do_usrsock_blocking_poll_thread(FAR void *param)
 
   /* Connect socket. */
 
-  ret = connect(test_sd[tidx], (FAR const struct sockaddr *)&addr, sizeof(addr));
+  ret = connect(test_sd[tidx], (FAR const struct sockaddr *)&addr,
+                sizeof(addr));
   TEST_ASSERT_EQUAL(0, ret);
 
   /* Allow main thread to hang usrsock daemon at this point. */
@@ -461,21 +519,6 @@ static FAR void * usrsock_blocking_poll_thread(FAR void *param)
 
 static void do_wake_test(enum e_test_type type, int flags)
 {
-  static const struct
-  {
-    pthread_startroutine_t fn;
-    bool stop_only_on_hang;
-  } thread_funcs[__TEST_TYPE_MAX] =
-    {
-      [TEST_TYPE_SOCKET]      = { usrsock_blocking_socket_thread, false },
-      [TEST_TYPE_CLOSE]       = { usrsock_blocking_close_thread, false },
-      [TEST_TYPE_CONNECT]     = { usrsock_blocking_connect_thread, true },
-      [TEST_TYPE_SETSOCKOPT]  = { usrsock_blocking_setsockopt_thread, false },
-      [TEST_TYPE_GETSOCKOPT]  = { usrsock_blocking_getsockopt_thread, false },
-      [TEST_TYPE_RECV]        = { usrsock_blocking_recv_thread, true },
-      [TEST_TYPE_SEND]        = { usrsock_blocking_send_thread, true },
-      [TEST_TYPE_POLL]        = { usrsock_blocking_poll_thread, true },
-    };
   int ret;
   int nthreads = (flags & TEST_FLAG_MULTI_THREAD) ? MAX_THREADS : 1;
   int tidx;
@@ -484,7 +527,8 @@ static void do_wake_test(enum e_test_type type, int flags)
 
   /* Start test daemon. */
 
-  TEST_ASSERT_EQUAL(OK, usrsocktest_daemon_start(&usrsocktest_daemon_config));
+  TEST_ASSERT_EQUAL(OK,
+                    usrsocktest_daemon_start(&usrsocktest_daemon_config));
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_active_sockets());
 
   /* Launch worker threads. */
@@ -498,7 +542,7 @@ static void do_wake_test(enum e_test_type type, int flags)
       TEST_ASSERT_EQUAL(OK, ret);
     }
 
-/* Let workers to start. */
+  /* Let workers to start. */
 
   for (tidx = 0; tidx < nthreads; tidx++)
     {
@@ -514,6 +558,7 @@ static void do_wake_test(enum e_test_type type, int flags)
     {
       sem_post(&tid_releasesem);
     }
+
   for (tidx = 0; tidx < nthreads; tidx++)
     {
       sem_wait(&tid_startsem);
@@ -538,6 +583,7 @@ static void do_wake_test(enum e_test_type type, int flags)
           TEST_ASSERT_EQUAL(OK, ret);
           tid[tidx] = -1;
         }
+
       TEST_ASSERT_FALSE(usrsocktest_test_failed);
 
       /* Stopping daemon should succeed. */
@@ -564,12 +610,13 @@ static void do_wake_test(enum e_test_type type, int flags)
           TEST_ASSERT_EQUAL(OK, ret);
           tid[tidx] = -1;
         }
+
       TEST_ASSERT_FALSE(usrsocktest_test_failed);
     }
 }
 
 /****************************************************************************
- * Name: WakeWithSignal test group setup
+ * Name: wake_with_signal test group setup
  *
  * Description:
  *   Setup function executed before each testcase in this test group
@@ -585,7 +632,7 @@ static void do_wake_test(enum e_test_type type, int flags)
  *
  ****************************************************************************/
 
-TEST_SETUP(WakeWithSignal)
+TEST_SETUP(wake_with_signal)
 {
   int i;
 
@@ -594,12 +641,13 @@ TEST_SETUP(WakeWithSignal)
       tid[i] = -1;
       test_sd[i] = -1;
     }
+
   sem_init(&tid_startsem, 0, 0);
   sem_init(&tid_releasesem, 0, 0);
 }
 
 /****************************************************************************
- * Name: WakeWithSignal test group teardown
+ * Name: wake_with_signal test group teardown
  *
  * Description:
  *   Setup function executed after each testcase in this test group
@@ -615,7 +663,7 @@ TEST_SETUP(WakeWithSignal)
  *
  ****************************************************************************/
 
-TEST_TEAR_DOWN(WakeWithSignal)
+TEST_TEAR_DOWN(wake_with_signal)
 {
   int ret;
   int i;
@@ -629,18 +677,20 @@ TEST_TEAR_DOWN(WakeWithSignal)
           ret = pthread_join(tid[i], NULL);
           assert(ret == OK);
         }
+
       if (test_sd[i] != -1)
         {
           close(test_sd[i]);
           test_sd[i] = -1;
         }
     }
+
   sem_destroy(&tid_startsem);
   sem_destroy(&tid_releasesem);
 }
 
 /****************************************************************************
- * Name: WakeBlockingConnect
+ * Name: wake_blocking_connect
  *
  * Description:
  *   Wake blocking connect with signal
@@ -656,7 +706,7 @@ TEST_TEAR_DOWN(WakeWithSignal)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, WakeBlockingConnect)
+TEST(wake_with_signal, wake_blocking_connect)
 {
   /* Configure test daemon. */
 
@@ -673,7 +723,7 @@ TEST(WakeWithSignal, WakeBlockingConnect)
 }
 
 /****************************************************************************
- * Name: WakeBlockingConnectMultiThread
+ * Name: wake_blocking_connect_multithread
  *
  * Description:
  *   Wake multiple blocking connect with signal
@@ -689,7 +739,7 @@ TEST(WakeWithSignal, WakeBlockingConnect)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, WakeBlockingConnectMultiThread)
+TEST(wake_with_signal, wake_blocking_connect_multithread)
 {
   /* Configure test daemon. */
 
@@ -706,7 +756,7 @@ TEST(WakeWithSignal, WakeBlockingConnectMultiThread)
 }
 
 /****************************************************************************
- * Name: WakeBlockingSend
+ * Name: wake_blocking_send
  *
  * Description:
  *   Wake blocking send with signal
@@ -722,7 +772,7 @@ TEST(WakeWithSignal, WakeBlockingConnectMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, WakeBlockingSend)
+TEST(wake_with_signal, wake_blocking_send)
 {
   /* Configure test daemon. */
 
@@ -739,7 +789,7 @@ TEST(WakeWithSignal, WakeBlockingSend)
 }
 
 /****************************************************************************
- * Name: WakeBlockingSendMultiThread
+ * Name: wake_blocking_send_multithread
  *
  * Description:
  *   Wake multiple blocking send with signal
@@ -755,7 +805,7 @@ TEST(WakeWithSignal, WakeBlockingSend)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, WakeBlockingSendMultiThread)
+TEST(wake_with_signal, wake_blocking_send_multithread)
 {
   /* Configure test daemon. */
 
@@ -770,8 +820,9 @@ TEST(WakeWithSignal, WakeBlockingSendMultiThread)
 
   do_wake_test(TEST_TYPE_SEND, TEST_FLAG_MULTI_THREAD);
 }
+
 /****************************************************************************
- * Name: WakeBlockingRecv
+ * Name: wake_blocking_recv
  *
  * Description:
  *   Wake blocking recv with signal
@@ -787,7 +838,7 @@ TEST(WakeWithSignal, WakeBlockingSendMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, WakeBlockingRecv)
+TEST(wake_with_signal, wake_blocking_recv)
 {
   /* Configure test daemon. */
 
@@ -805,7 +856,7 @@ TEST(WakeWithSignal, WakeBlockingRecv)
 }
 
 /****************************************************************************
- * Name: WakeBlockingRecvMultiThread
+ * Name: wake_blocking_recv_multithread
  *
  * Description:
  *   Wake multiple blocking recv with signal
@@ -821,7 +872,7 @@ TEST(WakeWithSignal, WakeBlockingRecv)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, WakeBlockingRecvMultiThread)
+TEST(wake_with_signal, wake_blocking_recv_multithread)
 {
   /* Configure test daemon. */
 
@@ -839,7 +890,7 @@ TEST(WakeWithSignal, WakeBlockingRecvMultiThread)
 }
 
 /****************************************************************************
- * Name: AbortBlockingConnect
+ * Name: abort_blocking_connect
  *
  * Description:
  *   Wake blocking connect with daemon abort
@@ -855,7 +906,7 @@ TEST(WakeWithSignal, WakeBlockingRecvMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, AbortBlockingConnect)
+TEST(wake_with_signal, abort_blocking_connect)
 {
   /* Configure test daemon. */
 
@@ -872,7 +923,7 @@ TEST(WakeWithSignal, AbortBlockingConnect)
 }
 
 /****************************************************************************
- * Name: AbortBlockingConnectMultiThread
+ * Name: abort_blocking_connect_multithread
  *
  * Description:
  *   Wake multiple blocking connect with daemon abort
@@ -888,7 +939,7 @@ TEST(WakeWithSignal, AbortBlockingConnect)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, AbortBlockingConnectMultiThread)
+TEST(wake_with_signal, abort_blocking_connect_multithread)
 {
   /* Configure test daemon. */
 
@@ -906,7 +957,7 @@ TEST(WakeWithSignal, AbortBlockingConnectMultiThread)
 }
 
 /****************************************************************************
- * Name: AbortBlockingSend
+ * Name: abort_blocking_send
  *
  * Description:
  *   Wake blocking send with daemon abort
@@ -922,7 +973,7 @@ TEST(WakeWithSignal, AbortBlockingConnectMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, AbortBlockingSend)
+TEST(wake_with_signal, abort_blocking_send)
 {
   /* Configure test daemon. */
 
@@ -939,7 +990,7 @@ TEST(WakeWithSignal, AbortBlockingSend)
 }
 
 /****************************************************************************
- * Name: AbortBlockingSendMultiThread
+ * Name: abort_blocking_send_multithread
  *
  * Description:
  *   Wake multiple blocking send with daemon abort
@@ -955,7 +1006,7 @@ TEST(WakeWithSignal, AbortBlockingSend)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, AbortBlockingSendMultiThread)
+TEST(wake_with_signal, abort_blocking_send_multithread)
 {
   /* Configure test daemon. */
 
@@ -973,7 +1024,7 @@ TEST(WakeWithSignal, AbortBlockingSendMultiThread)
 }
 
 /****************************************************************************
- * Name: AbortBlockingRecv
+ * Name: abort_blocking_recv
  *
  * Description:
  *   Wake blocking recv with daemon abort
@@ -989,7 +1040,7 @@ TEST(WakeWithSignal, AbortBlockingSendMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, AbortBlockingRecv)
+TEST(wake_with_signal, abort_blocking_recv)
 {
   /* Configure test daemon. */
 
@@ -1007,7 +1058,7 @@ TEST(WakeWithSignal, AbortBlockingRecv)
 }
 
 /****************************************************************************
- * Name: AbortBlockingRecvMultiThread
+ * Name: abort_blocking_recv_multithread
  *
  * Description:
  *   Wake multiple blocking recv with daemon abort
@@ -1023,7 +1074,7 @@ TEST(WakeWithSignal, AbortBlockingRecv)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, AbortBlockingRecvMultiThread)
+TEST(wake_with_signal, abort_blocking_recv_multithread)
 {
   /* Configure test daemon. */
 
@@ -1042,7 +1093,7 @@ TEST(WakeWithSignal, AbortBlockingRecvMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingConnect
+ * Name: pending_request_blocking_connect
  *
  * Description:
  *   Wake blocking connect with daemon abort (and daemon not handling pending
@@ -1059,7 +1110,7 @@ TEST(WakeWithSignal, AbortBlockingRecvMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingConnect)
+TEST(wake_with_signal, pending_request_blocking_connect)
 {
   /* Configure test daemon. */
 
@@ -1077,11 +1128,11 @@ TEST(WakeWithSignal, PendingRequestBlockingConnect)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingConnectMultiThread
+ * Name: pending_request_blocking_connect_multithread
  *
  * Description:
- *   Wake multiple blocking connect with daemon abort (and daemon not handling
- *   pending requests before abort)
+ *   Wake multiple blocking connect with daemon abort (and daemon not
+ *   handling pending requests before abort)
  *
  * Input Parameters:
  *   None
@@ -1094,7 +1145,7 @@ TEST(WakeWithSignal, PendingRequestBlockingConnect)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingConnectMultiThread)
+TEST(wake_with_signal, pending_request_blocking_connect_multithread)
 {
   /* Configure test daemon. */
 
@@ -1113,7 +1164,7 @@ TEST(WakeWithSignal, PendingRequestBlockingConnectMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingSend
+ * Name: pending_request_blocking_send
  *
  * Description:
  *   Wake blocking send with daemon abort (and daemon not handling pending
@@ -1130,7 +1181,7 @@ TEST(WakeWithSignal, PendingRequestBlockingConnectMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingSend)
+TEST(wake_with_signal, pending_request_blocking_send)
 {
   /* Configure test daemon. */
 
@@ -1148,7 +1199,7 @@ TEST(WakeWithSignal, PendingRequestBlockingSend)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingSendMultiThread
+ * Name: pending_request_blocking_send_multithread
  *
  * Description:
  *   Wake multiple blocking send with daemon abort (and daemon not handling
@@ -1165,7 +1216,7 @@ TEST(WakeWithSignal, PendingRequestBlockingSend)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingSendMultiThread)
+TEST(wake_with_signal, pending_request_blocking_send_multithread)
 {
   /* Configure test daemon. */
 
@@ -1184,7 +1235,7 @@ TEST(WakeWithSignal, PendingRequestBlockingSendMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingRecv
+ * Name: pending_request_blocking_recv
  *
  * Description:
  *   Wake blocking recv with daemon abort (and daemon not handling pending
@@ -1201,7 +1252,7 @@ TEST(WakeWithSignal, PendingRequestBlockingSendMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingRecv)
+TEST(wake_with_signal, pending_request_blocking_recv)
 {
   /* Configure test daemon. */
 
@@ -1220,7 +1271,7 @@ TEST(WakeWithSignal, PendingRequestBlockingRecv)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingRecvMultiThread
+ * Name: pending_request_blocking_recv_multithread
  *
  * Description:
  *   Wake multiple blocking recv with daemon abort (and daemon not handling
@@ -1237,7 +1288,7 @@ TEST(WakeWithSignal, PendingRequestBlockingRecv)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingRecvMultiThread)
+TEST(wake_with_signal, pending_request_blocking_recv_multithread)
 {
   /* Configure test daemon. */
 
@@ -1257,7 +1308,7 @@ TEST(WakeWithSignal, PendingRequestBlockingRecvMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingOpen
+ * Name: pending_request_blocking_open
  *
  * Description:
  *   Wake blocking open with daemon abort (and daemon not handling pending
@@ -1274,7 +1325,7 @@ TEST(WakeWithSignal, PendingRequestBlockingRecvMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingOpen)
+TEST(wake_with_signal, pending_request_blocking_open)
 {
   /* Configure test daemon. */
 
@@ -1293,7 +1344,7 @@ TEST(WakeWithSignal, PendingRequestBlockingOpen)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingOpenMultiThread
+ * Name: pending_request_blocking_open_multithread
  *
  * Description:
  *   Wake multiple blocking open with daemon abort (and daemon not handling
@@ -1310,7 +1361,7 @@ TEST(WakeWithSignal, PendingRequestBlockingOpen)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingOpenMultiThread)
+TEST(wake_with_signal, pending_request_blocking_open_multithread)
 {
   /* Configure test daemon. */
 
@@ -1330,7 +1381,7 @@ TEST(WakeWithSignal, PendingRequestBlockingOpenMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingClose
+ * Name: pending_request_blocking_close
  *
  * Description:
  *   Wake blocking close with daemon abort (and daemon not handling pending
@@ -1346,7 +1397,8 @@ TEST(WakeWithSignal, PendingRequestBlockingOpenMultiThread)
  *   None
  *
  ****************************************************************************/
-TEST(WakeWithSignal, PendingRequestBlockingClose)
+
+TEST(wake_with_signal, pending_request_blocking_close)
 {
   /* Configure test daemon. */
 
@@ -1365,7 +1417,7 @@ TEST(WakeWithSignal, PendingRequestBlockingClose)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingCloseMultiThread
+ * Name: pending_request_blocking_close_multithread
  *
  * Description:
  *   Wake multiple blocking close with daemon abort (and daemon not handling
@@ -1382,7 +1434,7 @@ TEST(WakeWithSignal, PendingRequestBlockingClose)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingCloseMultiThread)
+TEST(wake_with_signal, pending_request_blocking_close_multithread)
 {
   /* Configure test daemon. */
 
@@ -1402,7 +1454,7 @@ TEST(WakeWithSignal, PendingRequestBlockingCloseMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingPoll
+ * Name: pending_request_blocking_poll
  *
  * Description:
  *   Wake blocking poll with daemon abort (and daemon not handling pending
@@ -1419,7 +1471,7 @@ TEST(WakeWithSignal, PendingRequestBlockingCloseMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingPoll)
+TEST(wake_with_signal, pending_request_blocking_poll)
 {
   /* Configure test daemon. */
 
@@ -1438,7 +1490,7 @@ TEST(WakeWithSignal, PendingRequestBlockingPoll)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingPollMultiThread
+ * Name: pending_request_blocking_poll_multithread
  *
  * Description:
  *   Wake multiple blocking poll with daemon abort (and daemon not handling
@@ -1455,7 +1507,7 @@ TEST(WakeWithSignal, PendingRequestBlockingPoll)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingPollMultiThread)
+TEST(wake_with_signal, pending_request_blocking_poll_multithread)
 {
   /* Configure test daemon. */
 
@@ -1475,11 +1527,11 @@ TEST(WakeWithSignal, PendingRequestBlockingPollMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingSetSockOpt
+ * Name: pending_request_blocking_setsockopt
  *
  * Description:
- *   Wake blocking setsockopt with daemon abort (and daemon not handling pending
- *   request before abort)
+ *   Wake blocking setsockopt with daemon abort (and daemon not handling
+ *   pending request before abort)
  *
  * Input Parameters:
  *   None
@@ -1492,7 +1544,7 @@ TEST(WakeWithSignal, PendingRequestBlockingPollMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingSetSockOpt)
+TEST(wake_with_signal, pending_request_blocking_setsockopt)
 {
   /* Configure test daemon. */
 
@@ -1511,7 +1563,7 @@ TEST(WakeWithSignal, PendingRequestBlockingSetSockOpt)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingSetSockOptMultiThread
+ * Name: pending_request_blocking_setsockopt_multithread
  *
  * Description:
  *   Wake multiple blocking setsockopt with daemon abort (and daemon not
@@ -1528,7 +1580,7 @@ TEST(WakeWithSignal, PendingRequestBlockingSetSockOpt)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingSetSockOptMultiThread)
+TEST(wake_with_signal, pending_request_blocking_setsockopt_multithread)
 {
   /* Configure test daemon. */
 
@@ -1548,11 +1600,11 @@ TEST(WakeWithSignal, PendingRequestBlockingSetSockOptMultiThread)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingGetSockOpt
+ * Name: pending_request_blocking_getsockopt
  *
  * Description:
- *   Wake blocking getsockopt with daemon abort (and daemon not handling pending
- *   request before abort)
+ *   Wake blocking getsockopt with daemon abort (and daemon not handling
+ *   pending request before abort)
  *
  * Input Parameters:
  *   None
@@ -1565,7 +1617,7 @@ TEST(WakeWithSignal, PendingRequestBlockingSetSockOptMultiThread)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingGetSockOpt)
+TEST(wake_with_signal, pending_request_blocking_getsockopt)
 {
   /* Configure test daemon. */
 
@@ -1584,7 +1636,7 @@ TEST(WakeWithSignal, PendingRequestBlockingGetSockOpt)
 }
 
 /****************************************************************************
- * Name: PendingRequestBlockingGetSockOptMultiThread
+ * Name: pending_request_blocking_getsockopt_multithread
  *
  * Description:
  *   Wake multiple blocking getsockopt with daemon abort (and daemon not
@@ -1601,7 +1653,7 @@ TEST(WakeWithSignal, PendingRequestBlockingGetSockOpt)
  *
  ****************************************************************************/
 
-TEST(WakeWithSignal, PendingRequestBlockingGetSockOptMultiThread)
+TEST(wake_with_signal, pending_request_blocking_getsockopt_multithread)
 {
   /* Configure test daemon. */
 
@@ -1624,34 +1676,42 @@ TEST(WakeWithSignal, PendingRequestBlockingGetSockOptMultiThread)
  * Public Functions
  ****************************************************************************/
 
-TEST_GROUP(WakeWithSignal)
+TEST_GROUP(wake_with_signal)
 {
-  RUN_TEST_CASE(WakeWithSignal, WakeBlockingConnect);
-  RUN_TEST_CASE(WakeWithSignal, WakeBlockingConnectMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, WakeBlockingSend);
-  RUN_TEST_CASE(WakeWithSignal, WakeBlockingSendMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, WakeBlockingRecv);
-  RUN_TEST_CASE(WakeWithSignal, WakeBlockingRecvMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, AbortBlockingConnect);
-  RUN_TEST_CASE(WakeWithSignal, AbortBlockingConnectMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, AbortBlockingSend);
-  RUN_TEST_CASE(WakeWithSignal, AbortBlockingSendMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, AbortBlockingRecv);
-  RUN_TEST_CASE(WakeWithSignal, AbortBlockingRecvMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingConnect);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingConnectMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingSend);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingSendMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingRecv);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingRecvMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingOpen);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingOpenMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingClose);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingCloseMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingPoll);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingPollMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingSetSockOpt);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingSetSockOptMultiThread);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingGetSockOpt);
-  RUN_TEST_CASE(WakeWithSignal, PendingRequestBlockingGetSockOptMultiThread);
+  RUN_TEST_CASE(wake_with_signal, wake_blocking_connect);
+  RUN_TEST_CASE(wake_with_signal, wake_blocking_connect_multithread);
+  RUN_TEST_CASE(wake_with_signal, wake_blocking_send);
+  RUN_TEST_CASE(wake_with_signal, wake_blocking_send_multithread);
+  RUN_TEST_CASE(wake_with_signal, wake_blocking_recv);
+  RUN_TEST_CASE(wake_with_signal, wake_blocking_recv_multithread);
+  RUN_TEST_CASE(wake_with_signal, abort_blocking_connect);
+  RUN_TEST_CASE(wake_with_signal, abort_blocking_connect_multithread);
+  RUN_TEST_CASE(wake_with_signal, abort_blocking_send);
+  RUN_TEST_CASE(wake_with_signal, abort_blocking_send_multithread);
+  RUN_TEST_CASE(wake_with_signal, abort_blocking_recv);
+  RUN_TEST_CASE(wake_with_signal, abort_blocking_recv_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_connect);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_connect_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_send);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_send_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_recv);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_recv_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_open);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_open_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_close);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_close_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_poll);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_poll_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_setsockopt);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_setsockopt_multithread);
+  RUN_TEST_CASE(wake_with_signal, pending_request_blocking_getsockopt);
+  RUN_TEST_CASE(wake_with_signal,
+                pending_request_blocking_getsockopt_multithread);
 }
